[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pilot: BigJob Documentation
  - pilot.api: Abstract API Definition of the Pilot-API; This is not the implementation! Please see pilot.impl
    - pilot.api.api
    - pilot.api.compute
      - pilot.api.compute.api: Pilot Compute related entities.
    - pilot.api.data
      - pilot.api.data.api: This file contains the API for the PilotData Framework.
  - pilot.coordination: Private: Implementation of the coordination subsystem.
    - pilot.coordination.advert_adaptor
    - pilot.coordination.nocoord_adaptor
    - pilot.coordination.redis_adaptor
  - pilot.filemanagement: Private: Implementation of the filemanagement subsystem.
    - pilot.filemanagement.bliss_adaptor: Bliss based File Transfer Implementation
    - pilot.filemanagement.globusonline_adaptor: Globus Online based File Transfer
    - pilot.filemanagement.gs_adaptor: Google Storage based File Transfer Implementation
    - pilot.filemanagement.irods_adaptor: iRods based File Transfer Implementation
    - pilot.filemanagement.s3_adaptor: Amazon S3 based File Transfer Implementation
    - pilot.filemanagement.ssh_adaptor: SSH-based coordination scheme between manager and agent
    - pilot.filemanagement.webhdfs_adaptor
  - pilot.impl: BigJob-based Implementation of Pilot-API
    - pilot.impl.pilot_manager: ComputeDataService Module: A central implementation of the ComputeDataService
    - pilot.impl.pilot_manager_decentral: ComputeDataServiceDecentral Module: A decentral implementation of a ComputeDataService (see ComputeDataServiceDecentral).
    - pilot.impl.pilotcompute_manager: PilotCompute Module: Implementation of PilotComputeService, PilotCompute, ComputeUnit.
    - pilot.impl.pilotdata_manager: PilotData Module: Implementation of PilotData, PilotDataService and DataUnit
  - pilot.scheduler
    - pilot.scheduler.data_compute_affinity_scheduler: Affinity-aware scheduler that evaluates affinity labels and input/output data flow